==> qmmp-plugin-pack-2.2.2.tar.bz2: qmmp-plugin-pack-2.2.2/src/Input/modplug/translations/modplug_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>DecoderModPlugFactory</name>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="45"/>
        <source>ModPlug Plugin</source>
        <translation>Estensione ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="51"/>
        <source>ModPlug Files</source>
        <translation>File ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="135"/>
        <source>About ModPlug Audio Plugin</source>
        <translation>Informazioni sull&apos;estensione audio ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="136"/>
        <source>Qmmp ModPlug Audio Plugin</source>
        <translation>Estensione audio ModPlug per Qmmp</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="137"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Autori: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="138"/>
        <source>Based on the Modplug Plugin for Xmms</source>
        <translation>Basato sull&apos;estensione Modplug per Xmms</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="139"/>
        <source>Modplug Plugin developers:</source>
        <translation>Sviluppatori dell&apos;estensione Modplug:</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="140"/>
        <source>Olivier Lapicque &lt;olivierl@jps.net&gt;</source>
        <translation>Olivier Lapicque &lt;olivierl@jps.net&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="141"/>
        <source>Kenton Varda &lt;temporal@gauge3d.org&gt;</source>
        <translation>Kenton Varda &lt;temporal@gauge3d.org&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="142"/>
        <source>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</source>
        <translation>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</translation>
    </message>
</context>
<context>
    <name>ModPlugMetaDataModel</name>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="70"/>
        <source>Speed</source>
        <translation>Velocità</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="71"/>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="72"/>
        <location filename="../modplugmetadatamodel.cpp" line="93"/>
        <source>Samples</source>
        <translation>Campioni</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="73"/>
        <location filename="../modplugmetadatamodel.cpp" line="102"/>
        <source>Instruments</source>
        <translation>Strumenti</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="74"/>
        <source>Patterns</source>
        <translation>Schemi</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="75"/>
        <source>Channels</source>
        <translation>Canali</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="107"/>
        <source>Comment</source>
        <translation>Commento</translation>
    </message>
</context>
<context>
    <name>ModPlugSettingsDialog</name>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="14"/>
        <source>ModPlug Plugin Settings</source>
        <translation>Impostazioni estensione ModPlug</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="33"/>
        <source>Quality</source>
        <translation>Qualità</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="45"/>
        <source>Resolution</source>
        <translation>Risoluzione</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="51"/>
        <source>16 bit</source>
        <translation>16 bit</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="58"/>
        <source>8 bit</source>
        <translation>8 bit</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="74"/>
        <source>Channels</source>
        <translation>Canali</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="80"/>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="87"/>
        <source>Mono (downmix)</source>
        <translation>Mono (downmix)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="103"/>
        <source>Resampling</source>
        <translation>Ricampionatura</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="109"/>
        <source>Nearest (fastest)</source>
        <translation>Vicinissima (molto veloce)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="116"/>
        <source>Linear (fast)</source>
        <translation>Lineare (veloce)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="123"/>
        <source>Spline (good quality)</source>
        <translation>Spline (alta qualità)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="130"/>
        <source>8-tap Fir (extremely high quality)</source>
        <translation>8-tap FIR (altissima qualità)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="146"/>
        <source>Sampling Rate</source>
        <translation>Campionamento</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="152"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="159"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="166"/>
        <source>22050 Hz</source>
        <translation>22050 Hz</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="173"/>
        <source>11025 Hz</source>
        <translation>11025 Hz</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="184"/>
        <source>Effects</source>
        <translation>Effetti</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="190"/>
        <source>Reverb</source>
        <translation>Riverbero</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="202"/>
        <location filename="../modplugsettingsdialog.ui" line="467"/>
        <source>Depth (%)</source>
        <translation>Intensità (%)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="234"/>
        <location filename="../modplugsettingsdialog.ui" line="368"/>
        <location filename="../modplugsettingsdialog.ui" line="499"/>
        <location filename="../modplugsettingsdialog.ui" line="618"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="260"/>
        <location filename="../modplugsettingsdialog.ui" line="519"/>
        <source>Delay (ms)</source>
        <translation>Ritardo (ms)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="292"/>
        <source>40</source>
        <translation>40</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="324"/>
        <source>Bass Boost</source>
        <translation>Potenziamento bassi</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="336"/>
        <source>Amount (%)</source>
        <translation>Percentuale (%)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="394"/>
        <source>Range (Hz)</source>
        <translation>Campo di variazione (Hz)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="426"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="458"/>
        <source>Surround</source>
        <translation>Surround</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="551"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="577"/>
        <source>Preamp</source>
        <translation>Preamplificazione</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="586"/>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="656"/>
        <source>Note: Setting the preamp
too high may cause clipping!</source>
        <translation>Nota: impostare la preamplificazione troppo alta può causare dei tagli!</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="671"/>
        <source>Misc</source>
        <translation>Varie</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="677"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="683"/>
        <source>Use filename as song title</source>
        <translation>Usa nome file come titolo brano</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="690"/>
        <source>Noise reduction</source>
        <translation>Riduzione rumore</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="700"/>
        <source>Fast playlist info</source>
        <translation>Informazione rapida sulla scaletta</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="710"/>
        <source>Play Amiga MOD</source>
        <translation>Riproduci MOD Amiga</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="720"/>
        <source>Looping</source>
        <translation>Ripetizione</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="726"/>
        <source>Don&apos;t loop</source>
        <translation>Nessuna ripetizione</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="733"/>
        <source>Loop</source>
        <translation>Ripetere</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="750"/>
        <source>time(s)</source>
        <translation>volta/e</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="770"/>
        <source>Loop forever</source>
        <translation>Sempre</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-2.3.0.tar.bz2: qmmp-plugin-pack-2.3.0/src/Input/modplug/translations/modplug_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>DecoderModPlugFactory</name>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="45"/>
        <source>ModPlug Plugin</source>
        <translation>Estensione ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="51"/>
        <source>ModPlug Files</source>
        <translation>File ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="135"/>
        <source>About ModPlug Audio Plugin</source>
        <translation>Informazioni sull&apos;estensione audio ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="136"/>
        <source>Qmmp ModPlug Audio Plugin</source>
        <translation>Estensione audio ModPlug per Qmmp</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="137"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Autore: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="138"/>
        <source>Based on the Modplug Plugin for Xmms</source>
        <translation>Basato sull&apos;estensione Modplug per Xmms</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="139"/>
        <source>Modplug Plugin developers:</source>
        <translation>Sviluppatori dell&apos;estensione Modplug:</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="140"/>
        <source>Olivier Lapicque &lt;olivierl@jps.net&gt;</source>
        <translation>Olivier Lapicque &lt;olivierl@jps.net&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="141"/>
        <source>Kenton Varda &lt;temporal@gauge3d.org&gt;</source>
        <translation>Kenton Varda &lt;temporal@gauge3d.org&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="142"/>
        <source>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</source>
        <translation>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</translation>
    </message>
</context>
<context>
    <name>ModPlugMetaDataModel</name>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="70"/>
        <source>Speed</source>
        <translation>Velocità</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="71"/>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="72"/>
        <location filename="../modplugmetadatamodel.cpp" line="93"/>
        <source>Samples</source>
        <translation>Campioni</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="73"/>
        <location filename="../modplugmetadatamodel.cpp" line="102"/>
        <source>Instruments</source>
        <translation>Strumenti</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="74"/>
        <source>Patterns</source>
        <translation>Schemi</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="75"/>
        <source>Channels</source>
        <translation>Canali</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="107"/>
        <source>Comment</source>
        <translation>Commento</translation>
    </message>
</context>
<context>
    <name>ModPlugSettingsDialog</name>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="14"/>
        <source>ModPlug Plugin Settings</source>
        <translation>Impostazioni estensione ModPlug</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="33"/>
        <source>Quality</source>
        <translation>Qualità</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="45"/>
        <source>Resolution</source>
        <translation>Risoluzione</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="51"/>
        <source>16 bit</source>
        <translation>16 bit</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="58"/>
        <source>8 bit</source>
        <translation>8 bit</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="74"/>
        <source>Channels</source>
        <translation>Canali</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="80"/>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="87"/>
        <source>Mono (downmix)</source>
        <translation>Mono (downmix)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="103"/>
        <source>Resampling</source>
        <translation>Ricampionatura</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="109"/>
        <source>Nearest (fastest)</source>
        <translation>Vicinissima (molto veloce)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="116"/>
        <source>Linear (fast)</source>
        <translation>Lineare (veloce)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="123"/>
        <source>Spline (good quality)</source>
        <translation>Spline (alta qualità)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="130"/>
        <source>8-tap Fir (extremely high quality)</source>
        <translation>8-tap FIR (altissima qualità)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="146"/>
        <source>Sampling Rate</source>
        <translation>Campionamento</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="152"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="159"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="166"/>
        <source>22050 Hz</source>
        <translation>22050 Hz</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="173"/>
        <source>11025 Hz</source>
        <translation>11025 Hz</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="184"/>
        <source>Effects</source>
        <translation>Effetti</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="190"/>
        <source>Reverb</source>
        <translation>Riverbero</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="202"/>
        <location filename="../modplugsettingsdialog.ui" line="467"/>
        <source>Depth (%)</source>
        <translation>Intensità (%)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="234"/>
        <location filename="../modplugsettingsdialog.ui" line="368"/>
        <location filename="../modplugsettingsdialog.ui" line="499"/>
        <location filename="../modplugsettingsdialog.ui" line="618"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="260"/>
        <location filename="../modplugsettingsdialog.ui" line="519"/>
        <source>Delay (ms)</source>
        <translation>Ritardo (ms)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="292"/>
        <source>40</source>
        <translation>40</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="324"/>
        <source>Bass Boost</source>
        <translation>Potenziamento bassi</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="336"/>
        <source>Amount (%)</source>
        <translation>Percentuale (%)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="394"/>
        <source>Range (Hz)</source>
        <translation>Campo di variazione (Hz)</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="426"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="458"/>
        <source>Surround</source>
        <translation>Surround</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="551"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="577"/>
        <source>Preamp</source>
        <translation>Preamplificazione</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="586"/>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="656"/>
        <source>Note: Setting the preamp
too high may cause clipping!</source>
        <translation>Nota: impostare la preamplificazione troppo alta può causare dei tagli!</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="671"/>
        <source>Misc</source>
        <translation>Varie</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="677"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="683"/>
        <source>Use filename as song title</source>
        <translation>Usa nome file come titolo brano</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="690"/>
        <source>Noise reduction</source>
        <translation>Riduzione rumore</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="700"/>
        <source>Fast playlist info</source>
        <translation>Informazione rapida sulla playlist</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="710"/>
        <source>Play Amiga MOD</source>
        <translation>Riproduci MOD Amiga</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="720"/>
        <source>Looping</source>
        <translation>Ripetizione</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="726"/>
        <source>Don&apos;t loop</source>
        <translation>Nessuna ripetizione</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="733"/>
        <source>Loop</source>
        <translation>Ripetere</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="750"/>
        <source>time(s)</source>
        <translation>volta/e</translation>
    </message>
    <message>
        <location filename="../modplugsettingsdialog.ui" line="770"/>
        <source>Loop forever</source>
        <translation>Sempre</translation>
    </message>
</context>
</TS>
